# Icarus Api

_用以提供开发时的补全提示_

## 0.1.1
- utils
  - input() 输入
  - search() 搜索
  - exec_js(),exec_js_file()
  - walkdir更名为walk_dir
- ICARUS
  - platform() 获取操作系统类型
- coding
  - 增加json_loads(),json_dumps()
- cmds
  - REVERSE_SHELL() 生成反弹shell命令
  - NC_LISTEN() 生成netcat监听命令

## 0.1.0
- ICARUS
  - 调整了shell_exec的参数
- utils
  - 增加read_file,save_file
- net
  - 增加ssh,ssh_exec,ssh_run
  - 增加Tcp类，连接后可进行收发操作
- cmds
  - 新增cmds包，用于生成常见命令
  - PUT_PUBLIC_KEY() 生成写入公钥命令
## 0.0.9
- utils
  - 增加notice 调用系统通知 _(toast)_
- net
  - 完善net包提示
##0.0.8
- net
  - 增加request

##0.0.7
- utils
  - 增加walkdir，unzip
- net
  - 增加download

##0.0.6
- ICARUS
  - 增加shell_fetch，kill_task
## 0.0.5
整理api格式

## 0.0.4
- fofa
- coding
- vault


## 0.0.3
- docker

## 0.0.2
- utils.color

## 0.0.1
- ICARUS
- utils